function [xhistory] = graddesc(xinit,eta,timesteps)
%[xhistory] = graddesc(xinit,eta,timesteps)
%
%GRADDESC
%
% This function performs gradient descent on a function to find its
% minimum.
%
% xinit      is the starting point (should be a column vector or a scalar)
% eta        is the timestep
% timesteps  is the number of timesteps to simulate
%
% xhistory   is the output of the gradient descent; 
%            xhistory(timesteps) should hold the point to which the
%            descent converged
  
xdimensions = length(xinit);
xhistory = zeros(xdimensions,timesteps)*NaN;
xhistory(:,1) = xinit;

%?
%?
%?
%?






